from restApi import RESTClient
import logging
import threading
from hdbcli import dbapi

logging.basicConfig(
    filename='/home/epm/pythonDev/clearHanaData.log',  # Specify the log file
    filemode='w',  # Append the log messages to the file
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
    level=logging.DEBUG  # Set the logging level to DEBUG
)
# Create a logger
sysapp = logging.getLogger('clearHanaData')

restObj = RESTClient()
# urlFmt = "https://%s:%s/%s"

urlFmt = "http://%s/%s"
host = "172.17.0.14:31366"
tokenHeader = {'Authorization': 'YWRtaW46JjNVZUBURjlVcSo3dGdKQA==', 'Content-Type': 'application/json'}

def execute_sql(sql,hana_cursor,hana_name):
    sysapp.debug(sql)        
    try:
       hana_cursor.execute(sql) 
    except Exception as e:
        sysapp.error(hana_name,sql,e)

def cleanHana(inst):
    sysapp.info(inst)        
    try:
        hana_conn = dbapi.connect(
            address=inst['frpc_ip'],
            port=inst['frpc_hana_port'],
            user='SYSTEM',
            password='Wang_2017'
        )
        sysapp.info(hana_conn.isconnected())
        cursor = hana_conn.cursor()

        sysapp.debug('start to clean views for hana inst %s'%inst['name'])
        cursor.execute("SELECT * FROM sys.objects where OBJECT_TYPE='VIEW' and OBJECT_NAME like 'V%SEC%'")        
        # Fetch the data
        data = cursor.fetchall()        
        sysapp.debug('hana inst %s, view list %s'%(inst['name'],data))
        
        threadAry = []
        for row in data:
            sysapp.debug(row)
            sql = "drop view %s.%s" % (row['SCHEMA_NAME'], row['OBJECT_NAME'])
            #sysapp.debug(sql)
            threadi = threading.Thread(target=execute_sql,args=(inst['name'],sql,cursor))
            threadi.start()
            threadAry.append(threadi)
            sysapp.info('all threads start')
        for thread in threadAry:
            thread.join()
        sysapp.info('clean views  done.all threads complete for hana inst %s'%inst['name'])   

        sysapp.debug('start to clean procedures for hana inst %s'%inst['name'])
        #select procedure_name,definition,schema_name from sys.procedures where procedure_name like 'TC%'
        cursor.execute("SELECT procedure_name,schema_name FROM sys.procedures where procedure_name like 'TC%'")
        data = cursor.fetchall()        
        sysapp.debug('hana inst %s, procedures list %s'%(inst['name'],data))

        threadAry = []
        for row in data:
            sysapp.debug(row)
            sql = "drop procedure %s.%s" % (row['SCHEMA_NAME'], row['procedure_name'])
            threadi = threading.Thread(target=execute_sql,args=(inst['name'],sql,cursor))
            threadi.start()
            threadAry.append(threadi)
            sysapp.info('all threads start')
        for thread in threadAry:
            thread.join()
        sysapp.info('clean procedures done.all threads complete for hana inst %s'%inst['name'])    


        hana_conn.close()
    except Exception as e:
        sysapp.error(e)

try:
    sysapp.info('start, fetch from cmdb')
    
    restPath='epm/db/getHanaList'
    threadAry = []
    url = urlFmt % (host, restPath)
    sysapp.info(url)
    response = restObj.get(url, headers=tokenHeader)
    sysapp.debug(response.content)
    restObj.checkResponse(response.status_code)
    for hanaInst in response.json():
        #sysapp.info(app['name'])
        if hanaInst['env_ywid'] == '698' or hanaInst['env_ywid'] == '419':
            threadi = threading.Thread(target=cleanHana,args=(hanaInst,))
            threadi.start()
            threadAry.append(threadi)

    sysapp.info('all threads start')
    for thread in threadAry:
        thread.join()
    sysapp.info('all threads complete')

except Exception as e:
    sysapp.error(e)